@@ -105,7 +105,7 @@ class Update:
                     "guid",
                     "id",
                     "personnel_type_id",
-                    "personnel_type_name",
+                    # "personnel_type_name",
                 ]:
                     continue
                 if key not in person:
@@ -335,7 +335,8 @@ class Update:
             if "disabled" in p:
                 del p["disabled"]
             # p["first_name"] = p["first_name_ascii"]
-            # p["home_institution"] = p["home_institution_ascii"]
+            if (len(p["home_institution"]) < 125):
+                p["home_institution"][:125]
             # p["last_name"] = p["last_name_ascii"]
             # p["legal_name"] = f"{p['legal_last_name']},{p['legal_first_name']}"
             p["middle_name"] = ""
